@@ -101,6 +101,9 @@ class BaseExperiment:
 
         fit_or_cv (str): Flag. "FIT" when training the model, "CV" when performing cross-validation.
 
+        stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
+            Default: ``True``
+
         saved_model_types (dict): Dictionary specifying the saved model types and their frequencies.
 
     Note:
@@ -113,6 +116,7 @@ class BaseExperiment:
         project_name : str,
         X : "np.ndarray",
         y : "np.ndarray",
+        stratify: bool = True,
         X_val : Optional[Union["np.ndarray", "torch.Tensor", "pd.DataFrame"]] = None,
         y_val : Optional[Union["np.ndarray", "torch.Tensor", "pd.DataFrame"]] = None,
         X_test : Optional[Union["np.ndarray", "torch.Tensor", "pd.DataFrame"]]= None,
@@ -157,6 +161,9 @@ class BaseExperiment:
             random_number (int): The seed.
                 Default: ``0``
 
+            stratify (bool): Whether to use label-stratification in splitting data into train/val/test set.
+                Default: ``True``
+
             path (str): Base path for the project. Default is the current directory.
                 Default: ``'.'``
         
@@ -178,6 +185,10 @@ class BaseExperiment:
         self.y_test = y_test
         self.test_size = test_size
         self.n_classes = n_classes
+        self.stratify = stratify
+        if n_classes is None and self.stratify:
+            logger.info(f"Cannot perform label stratification in regression tasks. Setting stratify to False.")
+            self.stratify = False
         self.path = "." if path is None else path
         if self.path[-1] == "/":
             self.path = self.path[:-1]
@@ -316,8 +327,7 @@ class BaseExperiment:
         return self.model
 
     def get_data_module(
-        self,
-        stratify : bool = True
+        self
     )->Union["pl.LightningDataModule", Tuple["np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray","np.ndarray"]]:
         r"""Method for getting a datamodule.
 
@@ -333,9 +343,9 @@ class BaseExperiment:
             del self.data_module
         self.data_module = None
         data_module = None
-        if self.n_classes is None and stratify:
+        if self.n_classes is None and self.stratify:
             logger.info(f"Unable to stratify continuous targets. Will split the data without label stratification.")
-            stratify = False
+            self.stratify = False
         if isinstance(self.model, ConvNet) or isinstance(self.model, SegNet):
             if len(self.X.shape) > 2:
                 data_module = initialize_datamodule(
@@ -348,7 +358,7 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
             else: 
                 raise AssertionError("Wrong dimension for vision data. You must specify the dimensions of the data, not in a flattened way.")
@@ -364,7 +374,7 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
             
             if self.X_val is not None and self.y_val is not None and self.X_test is None and self.y_test is None:
@@ -378,7 +388,7 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
             
             if self.X_val is None and self.y_val is None and self.X_test is not None and self.y_test is not None:
@@ -392,7 +402,7 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
             if self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
                 data_module = initialize_datamodule(
@@ -405,7 +415,7 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
 
         elif isinstance(self.model, pl.LightningModule): # other lightning modules not in astrape
@@ -421,7 +431,7 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
             elif self.X_val is not None and self.y_val is not None and self.X_test is None and self.y_test is None:
                 data_module = initialize_datamodule(
@@ -434,7 +444,7 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
             
             elif self.X_val is None and self.y_val is None and self.X_test is not None and self.y_test is not None:
@@ -448,7 +458,7 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
 
             elif self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
@@ -462,14 +472,14 @@ class BaseExperiment:
                     y_test=self.y_test,
                     test_size=self.test_size,
                     random_state=self.random_state,
-                    stratify=stratify
+                    stratify=self.stratify
                 )
         elif isinstance(self.model, BaseEstimator):
             if self.X_test is None and self.y_test is None:
                 if self.n_classes is None:
-                    if stratify:
+                    if self.stratify:
                         logger.info(f"Unable to stratify continuous targets. Will split the data without label stratification.")
-                        stratify = False
+                        self.stratify = False
                     X_, X_test, y_, y_test = train_test_split(self.X, self.y, test_size=self.test_size)
                     X_train, X_val, y_train, y_val = train_test_split(X_, y_, test_size=self.test_size)
                 else:
@@ -539,7 +549,6 @@ class BaseExperiment:
         self,
         sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None,
         fit_or_cv : str = "FIT",
-        stratify : bool = True,
         **config        
     )->Union["pl.LightningModule", "BaseEstimator"]:
         r"""Method for training the model.
@@ -548,9 +557,6 @@ class BaseExperiment:
 
             sample_weight (np.ndarray or torch.Tensor, optional): If specified, this will be the weights for each sample.
                 Default: ``None``
-            
-            stratify (bool): Whether to use label-stratification in data splitting. Forced to be `False` when it is a regression task.
-                Default: ``True``
 
             fit_or_cv (str): Flag. "FIT" if in actual training, "CV" if in cross validation.
                 Default: ``"FIT"``
@@ -562,14 +568,14 @@ class BaseExperiment:
             `pl.LightningModule` or `BaseEstimator`: self.model
 
         """
-
+        
         if self.model is None:
             raise AssertionError("Model must be defined first. Use .model(model_type, **hparams) to declare a model.")
         
         self.fit_or_cv = fit_or_cv
         self.update_log_path()
         if self.data_module is None:
-            self.data_module = self.get_data_module(stratify=stratify)
+            self.data_module = self.get_data_module(stratify=self.stratify)
         if self.logger:
             self.logger.close()
             del self.logger
