@@ -34,6 +34,7 @@ class Experiment(BaseExperiment):
         test_size : float = 0.01,
         stack_models : bool = True,
         random_number : int = 0,
+        stratify : bool = True,
         path : Optional[str] = None
     )->None:
        
@@ -47,6 +48,7 @@ class Experiment(BaseExperiment):
             test_size=test_size,
             stack_models=stack_models,
             random_number=random_number,
+            stratify=stratify,
             path=path
         )
     def cross_validation(
